<?php
$lang['0_product'] = 'Produkt';
$lang['1_service'] = 'Service';
$lang['2_discount'] = 'Rabatt';
$lang['3_shipping'] = 'Frakt';
$lang['4_tax'] = 'Skatt';
$lang['addedit_billingform_template'] = 'L&auml;gg till/redigera Faktureringsmall';
$lang['addedit_completion_template'] = 'L&auml;gg till/redigera Slutf&ouml;randemall';
$lang['addedit_confirmorder_template'] = 'L&auml;gg till/redigera Bekr&auml;fta Ordermall';
$lang['addedit_gateway_complete_template'] = 'L&auml;gg till/redigera Gateway Complete Template';
$lang['addedit_invoice_template'] = 'L&auml;gg till/redigera Fakturamall';
$lang['addedit_paymentform_template'] = 'L&auml;gg till/redigera Betalningsmall';
$lang['address1'] = 'Adress 1';
$lang['address2'] = 'Adress 2';
$lang['address_handling'] = 'Adresshantering';
$lang['add_msg_template'] = 'L&auml;gg till en ny meddelandemall';
$lang['admin_email_addresses'] = 'Anv&auml;nda kommatecken f&ouml;r att separera e-postadresser om flera admins ska f&aring; bekr&auml;ftelse n&auml;r ny order har blivit tillagd.  ';
$lang['admin_email_template'] = 'Epostmall f&ouml;r admins';
$lang['amount'] = 'Belop';
$lang['amt_due'] = 'Amt. Due';
$lang['any'] = 'Vilken';
$lang['ask_delete'] = '&Auml;r du s&auml;ker p&aring; att du vill radera detta objekt?';
$lang['ask_delete_order'] = '&Auml;r du s&auml;ker p&aring; att du vill radera denna order?';
$lang['ask_delete_payment'] = '&Auml;r du s&auml;ker att du vill ta bort alla poster i denna betalning?';
$lang['ask_edit_billing'] = '&Auml;r du s&auml;ker p&aring; att du vill &auml;ndra p&aring; faktura informationen?';
$lang['ask_manual_payment'] = 'Are you sure you want to process a manual payment to the credit card for this amount?';
$lang['ask_saveprefs'] = 'Are you sure you want to adjust the preferences of this module?\nUse caution, incorrect adjustments may break a working website.';
$lang['ask_setorderstatus'] = 'A possible order status change has been detected, would you like to set the status to: ';
$lang['back'] = 'Tillbaka';
$lang['back_to_orders'] = 'Tillbaka till Ordrar';
$lang['backorder'] = 'Back Ordered';
$lang['balancedue'] = 'Balance Due (partially paid)';
$lang['bill_to'] = 'Skicka till';
$lang['billing'] = 'Fakturering';
$lang['billing_address'] = 'Faktureringsadress';
$lang['billing_form_templates'] = 'Faktureringsmallar';
$lang['billing_info'] = 'Fakturerings Information';
$lang['body'] = 'Meddelande';
$lang['cancel'] = 'Avbryt';
$lang['cancelled'] = 'Inst&auml;llda';
$lang['captcha_title'] = 'Captcha-Text';
$lang['cart_module'] = 'Kundvagnsmodulen';
$lang['cart_settings'] = 'Kundvagnsinst&auml;llningar';
$lang['cash'] = 'Kontant';
$lang['cc_AMEX'] = 'American Express';
$lang['cc_Discover'] = 'Discover';
$lang['cc_MasterCard'] = 'Mastercard';
$lang['cc_Visa'] = 'Visa';
$lang['city'] = 'Stad';
$lang['company'] = 'F&ouml;retag';
$lang['completed'] = 'F&auml;rdig';
$lang['completion_templates'] = 'Slutf&ouml;randemallar';
$lang['confirmed'] = 'Bekr&auml;ftad';
$lang['confirm_order'] = 'Bekr&auml;fta din order';
$lang['confirmation_form_templates'] = 'Bekr&auml;ftelsemallar';
$lang['confirmation_num'] = 'Bekr&auml;ftelsenummer';
$lang['cookie'] = 'Use address stored in a cookie';
$lang['country'] = 'Land';
$lang['coupon_code'] = 'Coupon Kod';
$lang['created'] = 'Skapad';
$lang['created_by'] = 'Skapad av';
$lang['create_invoice'] = 'Skapa en faktura f&ouml;r denna order';
$lang['create_invoice_for'] = 'Skapa faktura f&ouml;r order %s';
$lang['creditcard'] = 'Kreditkort';
$lang['creditcard_expiry'] = 'Kreditkort utg&aring;ngsdatum';
$lang['creditcard_number'] = 'Kreditkortsnummer';
$lang['creditcard_type'] = 'Kreditkorttyp';
$lang['creditcard_verifycode'] = 'Veriferingskod';
$lang['customer_name'] = 'Kundens namn';
$lang['date'] = 'Datum';
$lang['date_range'] = 'Datumintervall';
$lang['dateopt_exactdates'] = 'Exakta datum';
$lang['dateopt_7days'] = 'Senaste 7 dagarna';
$lang['dateopt_14days'] = 'Senaste 14 dagarna';
$lang['dateopt_30days'] = 'Senaste 30 dagarna';
$lang['dateopt_3months'] = 'Senaste 3 m&aring;naderna';
$lang['dateopt_6months'] = 'Senaste 6 m&aring;naderna';
$lang['dateopt_1year'] = 'Senaste &aring;ret';
$lang['default_templates'] = 'Standardmallar';
$lang['delete'] = 'Radera';
$lang['delivered'] = 'Skickad';
$lang['description'] = 'Beskrivning';
$lang['desc_order_by'] = 'Sortera efter {$billing->get_firstname()} {$billing->get_lastname()}';
$lang['destinations'] = 'Destinationer';
$lang['details'] = 'Detaljer';
$lang['dflt_billingform_template'] = 'Standard Faktureringsmall';
$lang['dflt_confirmorder_template'] = 'Standard Bekr&auml;ftning av Ordermall';
$lang['dflt_completion_template'] = 'Standard Slutf&ouml;randemall';
$lang['dflt_gateway_complete_template'] = 'Standard &quot;Gateway Transaction Complete&quot; mall';
$lang['dflt_invoice_message'] = 'Tack f&ouml;r att du handlar hos {sitename}.';
$lang['dflt_invoice_template'] = 'Standard Faktureringsmall';
$lang['dflt_paymentform_template'] = 'Standard Betalningsmall';
$lang['discount'] = 'Rabatt';
$lang['edit'] = 'Redigera';
$lang['edit_billing_info'] = 'Redigera faktureringsinformation';
$lang['edit_report_template'] = 'Editing Template for Report: %s';
$lang['end_date'] = 'Slutdatum';
$lang['email'] = 'Epost';
$lang['email_address'] = 'Epostadress';
$lang['email_invoice'] = 'Eposta denna faktura till kunden samt &ouml;vriga admins';
$lang['email_sent_to'] = 'Epost skicka till';
$lang['email_subject'] = 'Epost &Auml;mne';
$lang['error_badcaptcha'] = 'Captchas v&auml;rde var felaktigt ';
$lang['error_creditcard_expired'] = 'Kreditkortet har g&aring;tt ut. Kontakta din bank f&ouml;r att f&ouml;rnya ditt kort.';
$lang['error_encryption_problem'] = 'Ett problem uppstod vid kryptering eller dekryptering av data';
$lang['error_gateway_invalid_data'] = 'Could not confirm data validity from payment gateway module';
$lang['error_insufficientparams'] = 'En n&ouml;dv&auml;ndig parameter saknades';
$lang['error_invalid_address'] = 'The address specified is invalid (please ensure you completed all required fields correctly)';
$lang['error_invalidfield'] = 'F&ouml;ljande f&auml;lt &auml;r ogiltig: %s';
$lang['error_invalidgateway'] = 'Den valda gatewaymodulen &auml;r ogiltig f&ouml;r detta &auml;ndam&aring;l';
$lang['error_missingshippinginfo'] = 'Otillr&auml;cklig fraktinformation &auml;r angiven';
$lang['error_namexists'] = 'Ett objekt med detta namn finns redan';
$lang['error_nocartmodule'] = 'Hittade inte Cart modulen.  V&auml;nligen kontrollera att Cart modulen &auml;r installerad och &auml;r vald i  Products modulens inst&auml;llningar.';
$lang['error_noemailaddress'] = 'Ingen epostadress har satts i samband med detta anv&auml;ndarid ';
$lang['error_nofeumodule'] = 'Kunde inte hitta FrontEndUsers modulen';
$lang['error_nopaymentgateway'] = 'Ingen betalnings gateway &auml;r angiven';
$lang['error_noproductsmodule'] = 'Kunde inte hitta modulen Products';
$lang['error_norequiredgroup'] = 'V&auml;nligen ange en obligatorisk grupp i inst&auml;llningsdelen';
$lang['error_notloggedin'] = 'Anv&auml;ndaren &auml;r inte inloggad';
$lang['error_orderinvalid'] = 'Det finns ett problem med denna order (informationen &auml;r inkonsekvent)';
$lang['error_ordernotfound'] = 'Den valda ordern kunde inte hittas';
$lang['error_orderprocessing'] = 'An error occurred while processing this order (soft fail)';
$lang['error_paymentnotfound'] = 'The specified payment could not be found';
$lang['error_possible_hack'] = 'Detected a possible hack: your uid (%s) does not match the uid (%s) found for order %s.  Please contact your system administrator.';
$lang['error_requiressl'] = 'The gateway selected for use on this site requires a secure connection, which is not established yet';
$lang['error_retrieve_data'] = 'A problem occurred when trying to retrieve pertinent information from the database';
$lang['error_save'] = 'Error Saving a data item: %s';
$lang['error_security_key'] = 'The encryption key for this transaction could not be retrieved';
$lang['error_paymentgateway_incompatible'] = 'The selected payment gateway is incompatible with this order processing module.  Please contact the site administrator';
$lang['error_permissiondenied'] = '&Aring;tkomst nekad';
$lang['error_unknownstatus'] = 'Received an unknown status from the payment gateway';
$lang['error_usernotingroup'] = 'Den nuvarande anv&auml;ndaren som &auml;r inloggad tillh&ouml;r ingen obligatorisk grupp';
$lang['fax'] = 'Fax';
$lang['filter'] = 'Filter';
$lang['first_name'] = 'F&ouml;rnamn';
$lang['firstpage'] = '<<';
$lang['friendlyname'] = 'Order Hantering';
$lang['from'] = 'Fr&aring;n';
$lang['gateway'] = 'Gateway';
$lang['gateway_module'] = 'Payment Gateway Modul';
$lang['gateway_complete_templates'] = 'Gateway Complete Mallar';
$lang['gateway_failure_message'] = 'Din transaktion slutf&ouml;rdes inte. Antingen avslutades operationen eller s&aring;s uppstod n&aring;got annat fel. Bekr&auml;fta din betalningsinformation och f&ouml;rs&ouml;k igen. Din kundvagn &auml;r t&ouml;md f&ouml;r din s&auml;kerhet och bekv&auml;mlighet. Tack f&ouml;r er tid';
$lang['general_settings'] = 'Allm&auml;nna inst&auml;llningar';
$lang['get_address_from_feu'] = 'Anv&auml;nd Anv&auml;ndarprofil';
$lang['help_param_nocaptcha'] = 'Om denna parameter &auml;r inst&auml;lld, kommer captcha att st&auml;ngas av';
$lang['help_param_template'] = 'Specifera en icke standardmall f&ouml;r att anv&auml;nda som f&ouml;rsta val';
$lang['hold'] = 'Hold';
$lang['html'] = 'Html';
$lang['html_email'] = 'Skicka eposten i HTML format';
$lang['id'] = 'ID';
$lang['incomplete'] = 'Ofullst&auml;ndig (Delvis skickat)';
$lang['info_admin_invoice_template'] = 'Select a template that will be used for the printable invoice popup display when managing an order';
$lang['info_adminemail_template'] = 'This template controls the layout and content of the email that is sent to the authorized administrator when a new order is submitted';
$lang['info_allow_anon_checkout'] = 'If disabled, users will be required to have a valid FEU login to be able to check out';
$lang['info_allow_creditcard_entry'] = '<strong>Note:</strong> This information is stored in the database.<br/>Though encryption is used to store private data,<br/>it is recommended that this option never be used.<br/>Instead, please use a compatible payment gateway module.';
$lang['info_billingpage'] = '<strong>Note:</strong> This preference, and the others like it are used to allow the administrator to use different CMSMS pages for the different forms.  If &quot;none&quot; is specified, then the current page will be used.';
$lang['info_ccprocessing_module'] = 'Denna modul anv&auml;nds f&ouml;r manuell kreditkorts hantering ';
$lang['info_coupon_code'] = 'Ange en kupongkod f&ouml;r en eventuell rabatt';
$lang['info_default_templates'] = 'This form controls the content of the template when you click &#039;New Template&#039; in the &#039;Confirmation Form Templates&#039; tab.  Editing the text here will have no immediate effect on the appearance of your site';
$lang['info_edit_report_template'] = 'These templates determine the style and layout for a particular report';
$lang['info_encryption_key'] = 'This key is randomly generated when the module is installed.  Use caution when changing this value if there are already orders in the system.';
$lang['info_forcessl'] = '<strong>Note: Recommended</strong>.  If you are allowing customers to enter credit card information, you should enable this option and ensure that you have properly configured your site for SSL access to ensure that the transmission of credit card information is done over an encrypted connection.';
$lang['info_gateway_description'] = 'This information is sent to the payment gateway for each transaction, and may be used for information such as the name that shows up to clients on their credit card statements';
$lang['info_incomplete_timeout'] = 'Proposed orders that have had no activity in a set number of minutes can be set to incomplete automatically.  Set the value to 0 to disable this functionality';
$lang['info_invoicepage'] = '<strong>Note:</strong> This page is also used as the success and failure page for payment gateways';
$lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
$lang['info_order_notes'] = 'Supply some special notes for this order';
$lang['info_require_membergroup'] = 'This setting only applies if NOT allowing anonymous users to perform checkout';
$lang['info_skip_invoice_page'] = 'When allowing users to specify payment information,<br/>should they then procede to the invoice page,<br/>or directly to the transaction completion page?';
$lang['info_store_creditcard_data'] = '<strong>Note: <span style=&quot;color: red;&quot;>Not Recommended</span></strong> This option stores the user entered credit card information in the database for later use in the admin panel.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
$lang['info_useremail_template'] = 'This template controls the layout and content of the email that is sent to the user when a new order is submitted';
$lang['info_validcountries'] = 'Specify a list of country codes and country names (one entry per line) for the countries that will show up in the address list.  i.e: US=United States.  If no value is specified, the default country list will be used.';
$lang['info_validstates'] = 'Specify a list of state codes and names (one entry per line) for the states or provinces that will show up in the address list.  i.e: AB=Alberta.  If no value is specified, the default state list will be used.';
$lang['info_use_integer'] = 'Use only integer values';
$lang['interval_oneday'] = 'En dag';
$lang['interval_onemonth'] = 'En m&aring;nad';
$lang['interval_onequarter'] = 'Ett kvartal';
$lang['interval_oneweek'] = 'En vecka';
$lang['interval_oneyear'] = 'Ett &aring;r';
$lang['interval_twoweeks'] = 'Tv&aring; veckor';
$lang['invoice'] = 'Faktura';
$lang['invoiced'] = 'Fakturerad';
$lang['invoice_settings'] = 'Faktura inst&auml;llningar';
$lang['invoice_templates'] = 'Fakturamallar';
$lang['items'] = 'Objekt';
$lang['last_name'] = 'Efternamn';
$lang['last_modified'] = 'Senast upptaderad';
$lang['lastpage'] = '>>';
$lang['lbl_back'] = 'Tillbaka';
$lang['lbl_preferences'] = 'Inst&auml;llningar';
$lang['lbl_templates'] = 'Mallar';
$lang['legend_dates'] = 'Valda datum';
$lang['legend_reports'] = 'Reports';
$lang['message'] = 'Meddelande';
$lang['message_templates'] = 'Meddelandemall';
$lang['method'] = 'Metod';
$lang['moddescription'] = 'En enkel modul f&ouml;r bearbetning av ordrar';
$lang['modified'] = '&Auml;ndrad';
$lang['msg_async_transaction'] = 'Handled Async Transcation %s for order %s';
$lang['msg_order_cancelled'] = 'Order %s cancelled or declined';
$lang['msg_order_error'] = 'Error encountered for order %s';
$lang['msg_order_payment'] = 'Payment received for order %s.';
$lang['msg_order_pending'] = 'Order status changed to &quot;Pending&quot; on %s';
$lang['msg_payment_cancelled'] = 'Payment %s was cancelled for order %s';
$lang['msg_payment_declined'] = 'Payment %s was declined for order %s';
$lang['msg_payment_error'] = 'An error occurred on payment %s for order %s';
$lang['msg_payment_received'] = 'Payment %s (%s) was received for order %s';
$lang['msg_payment_removed'] = 'Payment removed from the order';
$lang['msg_payment_setbackwards'] = 'Attempted to set status of order %s backwards from PAID to PENDING';
$lang['name'] = 'Namn';
$lang['net'] = 'Netto';
$lang['net_price'] = 'Netto pris';
$lang['new_order_submitted'] = 'En ny order &auml;r tillagd';
$lang['next'] = 'N&auml;sta';
$lang['nextpage'] = '>';
$lang['no'] = 'nej';
$lang['no_items_in_cart'] = 'Det finns inga varor i din kundvagn. V&auml;nligen l&auml;gg till en vara innan du kan godk&auml;nna din best&auml;llning ';
$lang['no_report_data'] = 'Ingen data matchades';
$lang['none'] = 'Ingen';
$lang['notcancelledshipped'] = 'Inst&auml;llda eller fraktade';
$lang['notes'] = 'Noteringar';
$lang['notshipped'] = 'Ej levererad';
$lang['num'] = 'Nr.';
$lang['online'] = 'on-line';
$lang['order'] = 'Order';
$lang['orders'] = 'Ordrar';
$lang['order_confirm_form_templates'] = 'Confirm Order Form Templates';
$lang['order_details'] = 'Orderdetaljer';
$lang['order_notes'] = 'Ordernoteringar';
$lang['order_number'] = 'Order Nr.';
$lang['order_processing'] = 'Order behandling';
$lang['order_statistics'] = 'Orderstatistik';
$lang['order_summary'] = 'Ordersummering';
$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'Rabatt';
$lang['paid'] = 'Betald';
$lang['payment_amount'] = 'Amount of Payment';
$lang['payment_approved'] = 'Godk&auml;nd';
$lang['payment_cancelled'] = 'Avbruten';
$lang['payment_date'] = 'Payment Date';
$lang['payment_declined'] = 'Avvisad';
$lang['payment_error'] = 'Fel';
$lang['payment_form_templates'] = 'Payment Form Templates';
$lang['payment_gateway_settings'] = 'Payment Gateway Settings';
$lang['payment_history'] = 'Payment History';
$lang['payment_info'] = 'Payment Information';
$lang['payment_method'] = 'Payment Method';
$lang['payment_notprocessed'] = 'Not Processed';
$lang['payment_options'] = 'Payment Options';
$lang['payment_other'] = 'Annan';
$lang['payment_pending'] = 'Under bearbetning';
$lang['payment_status'] = 'Payment Status';
$lang['pending'] = 'Bearbetas';
$lang['phone'] = 'Telefon';
$lang['popup_new_window'] = 'Popup faktura in nytt f&ouml;nster';
$lang['postinstall'] = 'Installationen av Ordermodulen lyckades';
$lang['postuninstall'] = 'Ordermodulen och all associerad data &auml;r nu borttagen';
$lang['post_order_msg'] = 'Post Order Message';
$lang['postal'] = 'Postnr';
$lang['preferences'] = 'Inst&auml;llningar';
$lang['prevpage'] = '<';
$lang['price'] = 'Pris';
$lang['print_invoice'] = 'Skriv ut denna faktura';
$lang['procede_manual_checkout'] = 'Forts&auml;tt med manuell kassa';
$lang['process_manual_payment'] = 'Process Manual Payment';
$lang['process_new_transaction'] = 'Process CreditCard Transaction through Gateway';
$lang['process_order'] = 'Process Order';
$lang['product_id'] = 'Produkt ID';
$lang['promotions_module'] = 'Promotions Module';
$lang['promotions_settings'] = 'Promotions Settings';
$lang['prompt_address_property_map'] = 'Address to FEU Property Map';
$lang['prompt_address_retrieval'] = 'Address Retrieval Method';
$lang['prompt_admin_invoice_template'] = 'Printable Invoice Template';
$lang['prompt_allow_anon_checkout'] = 'Allow anonymous users to checkout';
$lang['prompt_allow_creditcard_entry'] = 'Till&aring;t kunder att l&auml;gga till kreditkorts information';
$lang['prompt_billingpage'] = 'Page to assume that the billing form will be displayed on.  This is usually the page with your <code>{Orders}</code> tag.';
$lang['prompt_ccprocessing_module'] = 'Credit Card Processing Gateway';
$lang['prompt_confirmpage'] = 'Page to use for the confirmation form';
$lang['prompt_datastore_timeout'] = 'Expiry period for temporary transaction information';
$lang['prompt_date_search_type'] = 'Filter Records that were ';
$lang['prompt_dflt_country'] = 'Default Country';
$lang['prompt_dflt_state'] = 'Default State';
$lang['prompt_email'] = 'Epostadress';
$lang['prompt_encryption_key'] = 'Encryption Key';
$lang['prompt_forcessl'] = 'Redirect the page to HTTPS for input of payment info';
$lang['prompt_gateway_description'] = 'Description to send to the payment gateway';
$lang['prompt_incomplete_timeout'] = 'Automatically set orders to incomplete <em>(if proposed)</em> after N minutes';
$lang['prompt_invoice_message'] = 'Message to appear at the top of all invoices';
$lang['prompt_invoicepage'] = 'Page to use for the invoice display';
$lang['prompt_of'] = 'Av';
$lang['prompt_ordernum_prefix'] = 'OrderNum Prefix';
$lang['prompt_page'] = 'Sida';
$lang['prompt_pagelimit'] = 'Antal ordrar per sida';
$lang['prompt_paymentpage'] = 'Page to use for the payment form';
$lang['prompt_permit_deletion'] = 'Allow deletion of orders';
$lang['prompt_requirepostal'] = 'Postal/Zip code is a required field on the billing form';
$lang['prompt_requirestate'] = 'State/Province is a required field in the billing form';
$lang['prompt_skip_invoice_page'] = 'Hoppas &ouml;ver fakturasidan';
$lang['prompt_store_creditcard_data'] = 'Permanently Store CreditCard Information';
$lang['prompt_template'] = 'Meddelandemall';
$lang['prompt_username'] = 'Anv&auml;ndarnamn';
$lang['prompt_validcountries'] = 'Valid Countries:';
$lang['prompt_validstates'] = 'Valid States:';
$lang['proposed'] = 'F&ouml;reslagen';
$lang['quantity'] = 'Antal';
$lang['really_uninstall'] = '&Auml;r du s&auml;ker p&aring; att du vill g&ouml;ra detta? Alla uppgifter i samband med den h&auml;r modulen kommer att g&aring; f&ouml;rlorade om du forts&auml;tter';
$lang['records_matching_query'] = 'Number of records matching your query';
$lang['regex'] = 'Regular Expression';
$lang['remember_last_address_used'] = 'Use the address from the last order';
$lang['report'] = 'Report';
$lang['reports'] = 'Reports';
$lang['report_recent_payments'] = 'Recent Payments';
$lang['report_shipping_costs'] = 'Shipping Costs';
$lang['report_subscr_picklist'] = 'Subscription Picklist';
$lang['report_templates'] = 'Report Templates';
$lang['return'] = 'Tillbaka';
$lang['require_group_membership'] = 'Require that all users that procede to the order stage be a member in this FEU Group';
$lang['security_settings'] = 'S&auml;kerhetsinst&auml;llningar';
$lang['select_action'] = 'V&auml;lj h&auml;ndelse';
$lang['select_one'] = 'V&auml;lj en';
$lang['select_invoice_template'] = 'V&auml;lj fakturamall';
$lang['send'] = 'Skicka';
$lang['send_message'] = 'Skicka ett meddelande till denna kund';
$lang['sent'] = 'Skickad';
$lang['ship_to'] = 'Skickad till';
$lang['shipped'] = 'Fraktad';
$lang['shipping'] = 'Frakt';
$lang['shipping_address'] = 'Frakt adress';
$lang['shipping_costs'] = 'Shipping Costs';
$lang['shipping_info'] = 'Frakt information';
$lang['shipping_info_for'] = 'Shipping Address For';
$lang['shipping_info_if_different'] = 'Frakt information <em>(Om annan &auml;n faktura adress)</em>';
$lang['shipping_message'] = 'Message related to this destination';
$lang['shipping_module'] = 'Fraktmodul';
$lang['shipping_settings'] = 'Fraktinst&auml;llningar';
$lang['shipping_total'] = 'Total frakt';
$lang['sku'] = 'SKU';
$lang['source'] = 'K&auml;lla';
$lang['special_instructions'] = 'Special instruktioner';
$lang['start_date'] = 'Startdatum';
$lang['state/province'] = 'Landskap';
$lang['status'] = 'Status';
$lang['subscription'] = 'Subscription';
$lang['subject'] = '&Auml;mne';
$lang['submit'] = 'Spara';
$lang['submitted'] = 'Sparad';
$lang['submit_payment_info'] = 'Spara betalningsinfo';
$lang['subscribed'] = 'Subscribed';
$lang['subtotal'] = 'Delsumma';
$lang['tax'] = 'Skatt';
$lang['tax_module'] = 'Skattmodul';
$lang['tax_settings'] = 'Skatt inst&auml;llningar';
$lang['template'] = 'Mall';
$lang['template_name'] = 'Mallnamn';
$lang['thank_you_for_order'] = 'Tack f&ouml;r ditt k&ouml;p fr&aring;n {sitename}';
$lang['timeout'] = 'Timed out';
$lang['title_adminemail_template'] = 'Administrator Email Template';
$lang['title_first_page'] = 'G&aring; till f&ouml;rsta sidan';
$lang['title_last_page'] = 'G&aring; till sista sidan';
$lang['title_manage_order'] = 'Administera ordrar';
$lang['title_manual_process'] = 'Manual Transaction Processing';
$lang['title_next_page'] = 'G&aring; till n&auml;sta sida';
$lang['title_prev_page'] = 'G&aring; till f&ouml;reg&aring;ende sida';
$lang['title_useremail_template'] = 'Anv&auml;ndare Epostmall';
$lang['to'] = 'Till';
$lang['total'] = 'Totalt';
$lang['tracking_num'] = 'Kollinummer';
$lang['transaction_id'] = 'Transaction Id';
$lang['transaction_successful'] = 'Payment processed successfully';
$lang['type'] = 'Typ';
$lang['update_status'] = 'Uppdatera satus';
$lang['unit_price'] = 'Enhetspris';
$lang['unit_weight'] = 'Enhetsvikt';
$lang['unknown'] = 'Ok&auml;nd';
$lang['unlimited'] = 'O&auml;ndligt';
$lang['username'] = 'Anv&auml;ndarnamn';
$lang['user_email_template'] = 'Anv&auml;ndare Epostmall';
$lang['view'] = 'Visa';
$lang['view_message'] = 'Visa meddelande';
$lang['view_messages'] = 'Visa meddelanden som har relation med denna order';
$lang['warning_https'] = '<strong>Warning!</strong> You are not using a secure (https) connection.  It is not recommended that you continue with this action without a secure connection.';
$lang['warning_manual_process'] = '<strong>Warning!</strong> This screen allows manual processing of credit card transactions using an online gateway.  Use caution!';
$lang['warning_orderstatus_paid'] = '<strong>Warning!</strong> This order has already been paid.  You should not be processing a manual payment on this order';
$lang['warning_orderstatus_cancelled'] = '<strong>Warning!</strong> This order has been cancelled.  You should not be processing a manual payment on this order';
$lang['warning_no_ccprocessing_gateway'] = '<strong>Warning!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
$lang['warning_order_paid_in_full'] = '<strong>Warning!</strong> This order already appears to have been paid in full.';
$lang['weight'] = 'Vikt';
$lang['within'] = 'Inom';
$lang['yes'] = 'Ja';
$lang['utma'] = '156861353.1779670065.1310491113.1310491113.1310491113.1';
$lang['utmz'] = '156861353.1310491113.1.1.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['qca'] = 'P0-1529175659-1310081076901';
$lang['utmb'] = '156861353.3.10.1310491113';
$lang['utmc'] = '156861353';
?>
